searchData={"items":[{"type":"module","doc":"Documentation for `SuperWorker`.\n\nSuperWorker library is a open-source library for building a fault-tolerant,\ndistributed, and scalable Elixir applications contributed by Ohhi.vn\n\nSome of the features of SuperWorker include:\n- New Supervisor for Elxir application.","title":"SuperWorker","ref":"SuperWorker.html"},{"type":"module","doc":"Documentation for `SuperWorker.Supervisor`.\nThis module is a new model for the Supervisor module.\nSupervisor supports the following features:\n- Group processes\n- Chain processes\n- Freedom processes","title":"SuperWorker.Supervisor","ref":"SuperWorker.Supervisor.html"},{"type":"module","doc":"Group processes are a set of processes that are started together. If one of the processes dies, all the processes in the group will be stopped.","title":"Group processes - SuperWorker.Supervisor","ref":"SuperWorker.Supervisor.html#module-group-processes"},{"type":"module","doc":"Chain processes are a set of processes that are started one after another. The output of the previous process is passed to the next process.","title":"Chain processes - SuperWorker.Supervisor","ref":"SuperWorker.Supervisor.html#module-chain-processes"},{"type":"module","doc":"Freedom processes are independent processes that are started separately.\n\nAll type of processes can be started in parallel & can be stopped individually or in a group.","title":"Freedom processes - SuperWorker.Supervisor","ref":"SuperWorker.Supervisor.html#module-freedom-processes"},{"type":"module","doc":"# Start a supervisor with 2 partitions & 2 groups:\n  alias SuperWorker.Supervisor, as: Sup\n  opts = [id: :sup1, number_of_partitions: 2, link: false]\n  Sup.start(opts)\n\n  Sup.add_group(:sup1, [id: :group1, restart_strategy: :one_for_all])\n  Sup.add_group_worker(:sup1, :group1, {Dev, :task, [15]}, [id: :g1_1])\n\n  Sup.add_group(:sup1, [id: :group2, restart_strategy: :one_for_all])\n  Sup.add_group_worker(:sup1, :group2, fn ->\n    receice do\n    msg ->\n      :ok\n    end\n  end, [id: :g2_2])","title":"Examples - SuperWorker.Supervisor","ref":"SuperWorker.Supervisor.html#module-examples"},{"type":"function","doc":"Add a chain to the supervisor.\nChain's options follow docs in `Chain` module.","title":"SuperWorker.Supervisor.add_chain/3","ref":"SuperWorker.Supervisor.html#add_chain/3"},{"type":"function","doc":"Add a worker to the chain in supervisor.","title":"SuperWorker.Supervisor.add_chain_worker/5","ref":"SuperWorker.Supervisor.html#add_chain_worker/5"},{"type":"function","doc":"Add a group to the supervisor.\nGroup's options follow docs in `Group` module.","title":"SuperWorker.Supervisor.add_group/3","ref":"SuperWorker.Supervisor.html#add_group/3"},{"type":"function","doc":"Add a  worker to a group in the supervisor.\nFunction's options follow `Worker` module.","title":"SuperWorker.Supervisor.add_group_worker/5","ref":"SuperWorker.Supervisor.html#add_group_worker/5"},{"type":"function","doc":"Add a standalone worker process to the supervisor.\nfunction for start worker can be a function or a {module, function, arguments}.\nStandalone worker is run independently from other workers follow :one_to_one strategy.\nIf worker crashes, it will check the restart strategy of worker then act accordingly.","title":"SuperWorker.Supervisor.add_standalone_worker/4","ref":"SuperWorker.Supervisor.html#add_standalone_worker/4"},{"type":"function","doc":"Send data to all workers in a group.","title":"SuperWorker.Supervisor.broadcast_to_group/4","ref":"SuperWorker.Supervisor.html#broadcast_to_group/4"},{"type":"function","doc":"Send data to all workers in current group of worker.\nUsing for communite between workers in the same group.","title":"SuperWorker.Supervisor.broadcast_to_my_group/1","ref":"SuperWorker.Supervisor.html#broadcast_to_my_group/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.child_spec/1","ref":"SuperWorker.Supervisor.html#child_spec/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.get_chain/3","ref":"SuperWorker.Supervisor.html#get_chain/3"},{"type":"function","doc":"get group structure from supervisor.","title":"SuperWorker.Supervisor.get_group/3","ref":"SuperWorker.Supervisor.html#get_group/3"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.get_host_partition/2","ref":"SuperWorker.Supervisor.html#get_host_partition/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.get_my_group/0","ref":"SuperWorker.Supervisor.html#get_my_group/0"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.get_my_supervisor/0","ref":"SuperWorker.Supervisor.html#get_my_supervisor/0"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.init/2","ref":"SuperWorker.Supervisor.html#init/2"},{"type":"function","doc":"Check if supervisor is running.\nreturn true if supervisor is running, otherwise return false.","title":"SuperWorker.Supervisor.is_running?/1","ref":"SuperWorker.Supervisor.html#is_running?/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.main_loop/2","ref":"SuperWorker.Supervisor.html#main_loop/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.remove_group_worker/4","ref":"SuperWorker.Supervisor.html#remove_group_worker/4"},{"type":"function","doc":"Send data to the entry worker in the chain.\nIf chain doesn't has any worker, it will be dropped.","title":"SuperWorker.Supervisor.send_to_chain/4","ref":"SuperWorker.Supervisor.html#send_to_chain/4"},{"type":"function","doc":"Send data to a worker in the group.","title":"SuperWorker.Supervisor.send_to_group/5","ref":"SuperWorker.Supervisor.html#send_to_group/5"},{"type":"function","doc":"Send data to a random worker in the group.","title":"SuperWorker.Supervisor.send_to_group_random/4","ref":"SuperWorker.Supervisor.html#send_to_group_random/4"},{"type":"function","doc":"Send data to other worker in the same group.","title":"SuperWorker.Supervisor.send_to_my_group/2","ref":"SuperWorker.Supervisor.html#send_to_my_group/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.send_to_my_group_random/1","ref":"SuperWorker.Supervisor.html#send_to_my_group_random/1"},{"type":"function","doc":"Send data directly to the worker (standalone, group, chain) in the supervisor.","title":"SuperWorker.Supervisor.send_to_worker/4","ref":"SuperWorker.Supervisor.html#send_to_worker/4"},{"type":"function","doc":"Start supervisor for run standalone please set option :link to false.\nresult format: {:ok, pid} or {:error, reason}","title":"SuperWorker.Supervisor.start/2","ref":"SuperWorker.Supervisor.html#start/2"},{"type":"function","doc":"Stop supervisor.\nType of shutdown:\n- :normal supervisor will send a message to worker for graceful shutdown. Not support for spawn process by function.\n- :kill supervisor will kill worker.","title":"SuperWorker.Supervisor.stop/3","ref":"SuperWorker.Supervisor.html#stop/3"},{"type":"module","doc":"Documentation for `SuperWorker.Supervisor.Chain`.","title":"SuperWorker.Supervisor.Chain","ref":"SuperWorker.Supervisor.Chain.html"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.add_worker/2","ref":"SuperWorker.Supervisor.Chain.html#add_worker/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.check_options/1","ref":"SuperWorker.Supervisor.Chain.html#check_options/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.get_all_workers/1","ref":"SuperWorker.Supervisor.Chain.html#get_all_workers/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.get_worker/2","ref":"SuperWorker.Supervisor.Chain.html#get_worker/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.kill_all_workers/1","ref":"SuperWorker.Supervisor.Chain.html#kill_all_workers/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.kill_worker/2","ref":"SuperWorker.Supervisor.Chain.html#kill_worker/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.new_data/2","ref":"SuperWorker.Supervisor.Chain.html#new_data/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.remove_worker/2","ref":"SuperWorker.Supervisor.Chain.html#remove_worker/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.restart_all_workers/1","ref":"SuperWorker.Supervisor.Chain.html#restart_all_workers/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.restart_worker/2","ref":"SuperWorker.Supervisor.Chain.html#restart_worker/2"},{"type":"type","doc":"","title":"SuperWorker.Supervisor.Chain.t/0","ref":"SuperWorker.Supervisor.Chain.html#t:t/0"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Chain.worker_exists?/2","ref":"SuperWorker.Supervisor.Chain.html#worker_exists?/2"},{"type":"module","doc":"This module is a wrapper for the configuration of the supervisor.","title":"SuperWorker.Supervisor.ConfigWrapper","ref":"SuperWorker.Supervisor.ConfigWrapper.html"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.ConfigWrapper.load/0","ref":"SuperWorker.Supervisor.ConfigWrapper.html#load/0"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.ConfigWrapper.load/1","ref":"SuperWorker.Supervisor.ConfigWrapper.html#load/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.ConfigWrapper.load_one/1","ref":"SuperWorker.Supervisor.ConfigWrapper.html#load_one/1"},{"type":"module","doc":"Documentation for `SuperWorker.Supervisor.Group`.","title":"SuperWorker.Supervisor.Group","ref":"SuperWorker.Supervisor.Group.html"},{"type":"function","doc":"A internal function. Add a worker to the group.","title":"SuperWorker.Supervisor.Group.add_worker/2","ref":"SuperWorker.Supervisor.Group.html#add_worker/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Group.broadcast/2","ref":"SuperWorker.Supervisor.Group.html#broadcast/2"},{"type":"function","doc":"Check, validate and convert key-value pairs to struct.","title":"SuperWorker.Supervisor.Group.check_options/1","ref":"SuperWorker.Supervisor.Group.html#check_options/1"},{"type":"function","doc":"Get all workers from the group.","title":"SuperWorker.Supervisor.Group.get_all_workers/1","ref":"SuperWorker.Supervisor.Group.html#get_all_workers/1"},{"type":"function","doc":"Get worker from the group.","title":"SuperWorker.Supervisor.Group.get_worker/2","ref":"SuperWorker.Supervisor.Group.html#get_worker/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Group.kill_all_workers/2","ref":"SuperWorker.Supervisor.Group.html#kill_all_workers/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Group.kill_worker/3","ref":"SuperWorker.Supervisor.Group.html#kill_worker/3"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Group.remove_worker/2","ref":"SuperWorker.Supervisor.Group.html#remove_worker/2"},{"type":"function","doc":"A internal function. Restart a worker in the group.","title":"SuperWorker.Supervisor.Group.restart_worker/2","ref":"SuperWorker.Supervisor.Group.html#restart_worker/2"},{"type":"type","doc":"","title":"SuperWorker.Supervisor.Group.t/0","ref":"SuperWorker.Supervisor.Group.html#t:t/0"},{"type":"function","doc":"Check if worker exists in the group.","title":"SuperWorker.Supervisor.Group.worker_exists?/2","ref":"SuperWorker.Supervisor.Group.html#worker_exists?/2"},{"type":"module","doc":"","title":"SuperWorker.Supervisor.MapQueue","ref":"SuperWorker.Supervisor.MapQueue.html"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.MapQueue.add/2","ref":"SuperWorker.Supervisor.MapQueue.html#add/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.MapQueue.get/2","ref":"SuperWorker.Supervisor.MapQueue.html#get/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.MapQueue.is_full?/1","ref":"SuperWorker.Supervisor.MapQueue.html#is_full?/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.MapQueue.new/1","ref":"SuperWorker.Supervisor.MapQueue.html#new/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.MapQueue.remove/2","ref":"SuperWorker.Supervisor.MapQueue.html#remove/2"},{"type":"module","doc":"Documentation for `SuperWorker.Supervisor.Worker`.","title":"SuperWorker.Supervisor.Worker","ref":"SuperWorker.Supervisor.Worker.html"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.check_chain_options/1","ref":"SuperWorker.Supervisor.Worker.html#check_chain_options/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.check_group_options/1","ref":"SuperWorker.Supervisor.Worker.html#check_group_options/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.check_standalone_options/1","ref":"SuperWorker.Supervisor.Worker.html#check_standalone_options/1"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.get/2","ref":"SuperWorker.Supervisor.Worker.html#get/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.remove/2","ref":"SuperWorker.Supervisor.Worker.html#remove/2"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.save/1","ref":"SuperWorker.Supervisor.Worker.html#save/1"},{"type":"type","doc":"","title":"SuperWorker.Supervisor.Worker.t/0","ref":"SuperWorker.Supervisor.Worker.html#t:t/0"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.update_process/4","ref":"SuperWorker.Supervisor.Worker.html#update_process/4"},{"type":"function","doc":"","title":"SuperWorker.Supervisor.Worker.update_process/5","ref":"SuperWorker.Supervisor.Worker.html#update_process/5"},{"type":"module","doc":"A wrapper module for storing terms in :persistent_term.\nGood choice for storing data that is rarely change.\nData is can acessed by all processes in the same node.\n\nKey was prefixed with the module name to avoid key collision.\n\nNote:\nBy default, TermStorage will be limited to 1GB of memory.\nIf you need to store more data, you can increase the limit by setting the `:persistent_term` option in the Erlang VM.","title":"SuperWorker.TermStorage","ref":"SuperWorker.TermStorage.html"},{"type":"function","doc":"Delete the key from the storage.","title":"SuperWorker.TermStorage.delete/1","ref":"SuperWorker.TermStorage.html#delete/1"},{"type":"function","doc":"Get the value of the key from the storage.","title":"SuperWorker.TermStorage.get/1","ref":"SuperWorker.TermStorage.html#get/1"},{"type":"function","doc":"Get all key/value in the storage.","title":"SuperWorker.TermStorage.get_all/0","ref":"SuperWorker.TermStorage.html#get_all/0"},{"type":"function","doc":"Put the value of the key to the storage.","title":"SuperWorker.TermStorage.put/2","ref":"SuperWorker.TermStorage.html#put/2"},{"type":"behaviour","doc":"","title":"SuperWorker.Worker","ref":"SuperWorker.Worker.html"},{"type":"callback","doc":"","title":"SuperWorker.Worker.error/2","ref":"SuperWorker.Worker.html#c:error/2"},{"type":"callback","doc":"","title":"SuperWorker.Worker.init/1","ref":"SuperWorker.Worker.html#c:init/1"},{"type":"callback","doc":"","title":"SuperWorker.Worker.spec/1","ref":"SuperWorker.Worker.html#c:spec/1"},{"type":"callback","doc":"","title":"SuperWorker.Worker.start/2","ref":"SuperWorker.Worker.html#c:start/2"},{"type":"callback","doc":"","title":"SuperWorker.Worker.start_link/2","ref":"SuperWorker.Worker.html#c:start_link/2"},{"type":"callback","doc":"","title":"SuperWorker.Worker.terminate/2","ref":"SuperWorker.Worker.html#c:terminate/2"},{"type":"extras","doc":"# Intro\n\nThe library support for auto scale & distritubed for Elixir application.\nHelp dev can easily work with concurrency.\n\n*Note: Library is still developing, please don't use for product.*","title":"Readme","ref":"readme.html"},{"type":"extras","doc":"Just declare function for worker (task) and input (in param or stream) and run.\nLibrary is created for dev can add workers in runtime without care too much about design supervisor tree.\nIt's matched with dynamic typed language like Elixir.","title":"Guide - Readme","ref":"readme.html#guide"},{"type":"extras","doc":"Support new kind of process, chain processes is made for easy create a powerful stream processing.","title":"Features - Readme","ref":"readme.html#features"},{"type":"extras","doc":"Support three type of processes in one supervisor. Can declare by config or add in runtime.\n\n```mermaid\ngraph LR\nClient(Client) <-->|api| Supervisor\n    Supervisor--> Group_1\n    Supervisor--> Chain_1\n    Supervisor-->Worker_standalone1\n    Supervisor-->Worker_standalone2\n    Group_1-->Worker_g1\n    Group_1-->Worker_g2\n    Group_1-->Worker_g3\n    Chain_1-->Worker_c1\n    Worker_c1-->Worker_c2\n    Worker_c2-->Worker_c3\n```\n\n**Type of processes:**\n\n- Group processes\n- Chain processes\n- Freedom processes","title":"Supervisor - Readme","ref":"readme.html#supervisor"},{"type":"extras","doc":"All processes in supervisor have same group_id.\nIf a process in group is crashed, all other processes will be died follow.\nAvoid using trap_exit in process to avoid side effect.\n\nSupport send message to worker or broadcast to all workers in a group. Dev don't need to implement a way for transfer data to worker.\n\n```mermaid\ngraph LR\n    Group_1-->Worker_1\n    Group_1-->Worker_2\n    Group_1-->Worker_3\n```","title":"Group processes - Readme","ref":"readme.html#group-processes"},{"type":"extras","doc":"Support chain task type. The data after process in a process will be passed to next process in chain.\nIf a process is crashed, all other process in chain will be die follow.\n\nFrom foreign process data can pass to chain (first worker in chain or directly to a worker with id) by Supervisor APIs.\n\nCan config function to call in the end of chain or self implement code in the last worker in the chain.\n\n```mermaid\ngraph LR\n    Worker_c1-->Worker_c2\n    Worker_c2-->Worker_c3\n```","title":"Chain processes - Readme","ref":"readme.html#chain-processes"},{"type":"extras","doc":"This for standalone worker run in supervisor, it has owner restart strategy.\nIf a standalone worker is crashed, it doesn't affect to other standalone workers or workers in group/chain.\n\n```mermaid\ngraph LR\n    Supervisor-->Worker_standalone1\n    Supervisor-->Worker_standalone2\n    Supervisor-->Worker_standalone3\n```","title":"Standalone processes - Readme","ref":"readme.html#standalone-processes"},{"type":"extras","doc":"- Support GenServer.\n- Callback module for easy understand & implement.\n- Multiprocess per chain node.\n- Auto scale for chain.\n- Distributed in cluster.","title":"Planned features - Readme","ref":"readme.html#planned-features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}